from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .community import Community


class CommunityChatAdded(TelegramObject):
    """
    Describes a service message about a chat or a bot being added to a community.

    Source: https://core.telegram.org/bots/api#communitychatadded
    """

    community: Community
    """The new community to which the chat or the bot belongs"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, community: Community, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(community=community, **__pydantic_kwargs)
