from .base import TelegramObject


class CommunityChatRemoved(TelegramObject):
    """
    Describes a service message about a chat or a bot being removed from a community. Currently holds no information.

    Source: https://core.telegram.org/bots/api#communitychatremoved
    """
