from .base import TelegramObject


class DisabledButton(TelegramObject):
    """
    This object represents a disabled button which does nothing. Currently holds no information.

    Source: https://core.telegram.org/bots/api#disabledbutton
    """
